@@ -1,8 +1,8 @@
 import json
 import math
 import pathlib
-from abc import abstractmethod
 import tempfile
+from abc import abstractmethod
 from typing import (
     Final,
     Iterable,
@@ -13,21 +13,27 @@ from typing import (
     Protocol,
     Sequence,
     Set,
-    Tuple,
     Type,
     TypeVar,
     Union,
+    cast,
 )
 
 import fasttext
 import torch
 import torch.jit
 import transformers
-from bidict import bidict, BidirectionalMapping
+from bidict import BidirectionalMapping, bidict
 from loguru import logger
 from torch import nn
 from torch.nn.utils.rnn import pack_padded_sequence, pad_sequence
-from transformers.tokenization_utils_base import BatchEncoding, TokenSpan
+from transformers.tokenization_utils_base import (
+    BatchEncoding,
+    PreTokenizedInput,
+    TokenSpan,
+)
+
+from typing_extensions import Self
 
 
 class LexingError(Exception):
@@ -43,58 +49,41 @@ def integer_dropout(t: torch.Tensor, fill_value: int, p: float) -> torch.Tensor:
     return t.masked_fill(mask, fill_value)
 
 
-_T_SupportsTo = TypeVar("_T_SupportsTo", bound="SupportsTo")
-
-
 class SupportsTo(Protocol):
     @abstractmethod
-    def to(self: _T_SupportsTo, device: Union[str, torch.device]) -> _T_SupportsTo:
+    def to(self, device: Union[str, torch.device]) -> Self:
         raise NotImplementedError
 
 
 _T_LEXER_SENT = TypeVar("_T_LEXER_SENT")
 _T_LEXER_BATCH = TypeVar("_T_LEXER_BATCH")
 
-_T_Lexer = TypeVar("_T_Lexer", bound="Lexer")
-
 
 class Lexer(Protocol[_T_LEXER_SENT, _T_LEXER_BATCH]):
+    output_dim: Final[int]
 
-    output_dim: int
-
-    @abstractmethod
     def encode(self, tokens_sequence: Sequence[str]) -> _T_LEXER_SENT:
-        raise NotImplementedError
+        ...
 
-    @abstractmethod
     def make_batch(self, batch: Sequence[_T_LEXER_SENT]) -> _T_LEXER_BATCH:
-        raise NotImplementedError
+        ...
 
-    @abstractmethod
     def save(self, model_path: pathlib.Path, save_weights: bool):
-        raise NotImplementedError
+        ...
+
+    def __call__(self, inpt: _T_LEXER_BATCH) -> torch.Tensor:
+        ...
 
     @classmethod
-    @abstractmethod
-    def load(cls: Type[_T_Lexer], model_path: pathlib.Path) -> _T_Lexer:
-        raise NotImplementedError
-
-    @abstractmethod
-    def __call__(self, inpt: _T_LEXER_BATCH) -> torch.Tensor:
-        raise NotImplementedError
-
-
-_T_CharRNNLexerBatch = TypeVar("_T_CharRNNLexerBatch", bound="CharRNNLexerBatch")
-
+    def load(cls, model_path: pathlib.Path) -> Self:
+        ...
 
 class CharRNNLexerBatch(NamedTuple):
     encoding: torch.Tensor
     sent_lengths: List[int]
     word_lengths: torch.Tensor
 
-    def to(
-        self: _T_CharRNNLexerBatch, device: Union[str, torch.device]
-    ) -> _T_CharRNNLexerBatch:
+    def to(self, device: Union[str, torch.device]) -> Self:
         return type(self)(
             encoding=self.encoding.to(device=device),
             sent_lengths=self.sent_lengths,
@@ -102,9 +91,6 @@ class CharRNNLexerBatch(NamedTuple):
         )
 
 
-_T_CharRNNLexer = TypeVar("_T_CharRNNLexer", bound="CharRNNLexer")
-
-
 class CharRNNLexer(nn.Module):
     """A lexer encoding words by running a bi-RNN on their characters
 
@@ -192,11 +178,7 @@ class CharRNNLexer(nn.Module):
         if token in self.special_tokens:
             res = [self.special_tokens_idx]
         else:
-            res = [
-                idx
-                for idx in (self.vocabulary.get(c) for c in token)
-                if idx is not None
-            ]
+            res = [idx for idx in (self.vocabulary.get(c) for c in token) if idx is not None]
             if not res:
                 res = [self.pad_idx]
         return torch.tensor(res, dtype=torch.long)
@@ -234,9 +216,7 @@ class CharRNNLexer(nn.Module):
                     "char_embeddings_dim": self.char_embeddings_dim,
                     "output_dim": self.output_dim,
                     "special_tokens": list(self.special_tokens),
-                    "charset": [
-                        self.vocabulary.inverse[i] for i in range(len(self.vocabulary))
-                    ],
+                    "charset": [self.vocabulary.inverse[i] for i in range(len(self.vocabulary))],
                 },
                 out_stream,
             )
@@ -244,7 +224,7 @@ class CharRNNLexer(nn.Module):
             torch.save(self.state_dict(), model_path / "weights.pt")
 
     @classmethod
-    def load(cls: Type[_T_CharRNNLexer], model_path: pathlib.Path) -> _T_CharRNNLexer:
+    def load(cls, model_path: pathlib.Path) -> Self:
         with open(model_path / "config.json") as in_stream:
             config = json.load(in_stream)
         res = cls(**config)
@@ -254,18 +234,13 @@ class CharRNNLexer(nn.Module):
         return res
 
     @classmethod
-    def from_chars(
-        cls: Type[_T_CharRNNLexer], chars: Iterable[str], **kwargs
-    ) -> _T_CharRNNLexer:
+    def from_chars(cls, chars: Iterable[str], **kwargs) -> Self:
         charset = sorted(set(chars))
         if wrong := [c for c in charset if len(c) > 1]:
             raise ValueError(f"Characters of length > 1 in charset: {wrong}")
         return cls(charset=["<pad>", "<special>", *charset], **kwargs)
 
 
-_T_FastTextLexer = TypeVar("_T_FastTextLexer", bound="FastTextLexer")
-
-
 class FastTextLexer(nn.Module):
     """
     This is subword model using FastText as backend.
@@ -293,16 +268,14 @@ class FastTextLexer(nn.Module):
             torch.randint(high=self.vocab_size, size=(self.output_dim,)),
             torch.arange(self.output_dim),
         ].unsqueeze(0)
-        weights = torch.cat(
-            (weights, torch.zeros((1, self.output_dim)), root_embedding), dim=0
-        ).to(torch.float)
-        weights.requires_grad = True
-        self.embeddings = nn.Embedding.from_pretrained(
-            weights, padding_idx=self.vocab_size
+        weights = torch.cat((weights, torch.zeros((1, self.output_dim)), root_embedding), dim=0).to(
+            torch.float
         )
+        weights.requires_grad = True
+        self.embeddings = nn.Embedding.from_pretrained(weights, padding_idx=self.vocab_size)
         self.special_tokens: Set = set([] if special_tokens is None else special_tokens)
         self.special_tokens_idx: Final[int] = self.vocab_size + 1
-        self.pad_idx: Final[int] = self.embeddings.padding_idx
+        self.pad_idx: Final[int] = cast(int, self.embeddings.padding_idx)
 
     def subwords_idxes(self, token: str) -> torch.Tensor:
         """Returns a list of ft subwords indexes a token"""
@@ -340,9 +313,7 @@ class FastTextLexer(nn.Module):
         """
         subword_indices = [self.word2subcodes(token) for token in tokens_sequence]
         # shape: sentence_length×num_subwords_in_longest_word
-        return pad_sequence(
-            subword_indices, padding_value=self.pad_idx, batch_first=True
-        )
+        return pad_sequence(subword_indices, padding_value=self.pad_idx, batch_first=True)
 
     def make_batch(self, batch: Sequence[torch.Tensor]) -> torch.Tensor:
         """Pad a batch of sentences.
@@ -389,9 +360,9 @@ class FastTextLexer(nn.Module):
 
     @classmethod
     def load(
-        cls: Type[_T_FastTextLexer],
+        cls,
         model_path: pathlib.Path,
-    ) -> _T_FastTextLexer:
+    ) -> Self:
         with open(model_path / "config.json") as in_stream:
             config = json.load(in_stream)
         res = cls.from_fasttext_model(model_path / "fasttext_model.bin", **config)
@@ -401,17 +372,15 @@ class FastTextLexer(nn.Module):
         return res
 
     @classmethod
-    def from_fasttext_model(
-        cls: Type[_T_FastTextLexer], model_file: Union[str, pathlib.Path], **kwargs
-    ) -> _T_FastTextLexer:
+    def from_fasttext_model(cls, model_file: Union[str, pathlib.Path], **kwargs) -> Self:
         return cls(fasttext.load_model(str(model_file)), **kwargs)
 
     @classmethod
     def from_raw(
-        cls: Type[_T_FastTextLexer],
+        cls,
         raw_text_path: Union[str, pathlib.Path],
         **kwargs,
-    ) -> _T_FastTextLexer:
+    ) -> Self:
         logger.info("Training fasttext model")
         # TODO: make the hyperparameters here configurable?
         model = fasttext.train_unsupervised(
@@ -421,10 +390,10 @@ class FastTextLexer(nn.Module):
 
     @classmethod
     def from_sents(
-        cls: Type[_T_FastTextLexer],
+        cls,
         sents: Iterable[List[str]],
         **kwargs,
-    ) -> _T_FastTextLexer:
+    ) -> Self:
         with tempfile.TemporaryDirectory() as tmp_dir:
             train_file = pathlib.Path(tmp_dir) / "train.txt"
             with open(train_file, "w") as out_stream:
@@ -434,9 +403,6 @@ class FastTextLexer(nn.Module):
             return cls.from_raw(train_file, **kwargs)
 
 
-_T_WordEmbeddingsLexer = TypeVar("_T_WordEmbeddingsLexer", bound="WordEmbeddingsLexer")
-
-
 class WordEmbeddingsLexer(nn.Module):
     """
     This is the basic lexer wrapping an embedding layer.
@@ -465,17 +431,13 @@ class WordEmbeddingsLexer(nn.Module):
             )
         except ValueError as e:
             raise ValueError("Duplicated words in vocabulary") from e
-        self.embedding = nn.Embedding(
-            len(self.vocabulary) + 1, embeddings_dim, padding_idx=0
-        )
-        self.output_dim = embeddings_dim
+        self.embedding = nn.Embedding(len(self.vocabulary) + 1, embeddings_dim, padding_idx=0)
+        self.output_dim: Final[int] = embeddings_dim
         self.unk_word_idx = self.vocabulary[unk_word]
         self.word_dropout = word_dropout
         self._dpout = 0.0
 
-    def train(
-        self: _T_WordEmbeddingsLexer, mode: bool = True
-    ) -> _T_WordEmbeddingsLexer:
+    def train(self, mode: bool = True) -> Self:
         if mode:
             self._dpout = self.word_dropout
         else:
@@ -487,21 +449,17 @@ class WordEmbeddingsLexer(nn.Module):
         Takes words sequences codes as integer sequences and returns the embeddings
         """
         if self._dpout:
-            word_sequences = integer_dropout(
-                word_sequences, self.unk_word_idx, self._dpout
-            )
+            word_sequences = integer_dropout(word_sequences, self.unk_word_idx, self._dpout)
         return self.embedding(word_sequences)
 
     def encode(self, tokens_sequence: Sequence[str]) -> torch.Tensor:
         """Map word tokens to integer indices."""
-        word_idxes = [
-            self.vocabulary.get(token, self.unk_word_idx) for token in tokens_sequence
-        ]
+        word_idxes = [self.vocabulary.get(token, self.unk_word_idx) for token in tokens_sequence]
         return torch.tensor(word_idxes)
 
     def make_batch(self, batch: Sequence[torch.Tensor]) -> torch.Tensor:
         """Pad a batch of sentences with zeros."""
-        return pad_sequence(batch, padding_value=0, batch_first=True)
+        return pad_sequence(cast(List, batch), padding_value=0, batch_first=True)
 
     def save(self, model_path: pathlib.Path, save_weights: bool = True):
         model_path.mkdir(exist_ok=True, parents=True)
@@ -513,8 +471,7 @@ class WordEmbeddingsLexer(nn.Module):
                     "embeddings_dim": self.output_dim,
                     "unk_word": self.vocabulary.inverse[self.unk_word_idx],
                     "vocabulary": [
-                        self.vocabulary.inverse[i]
-                        for i in range(1, len(self.vocabulary) + 1)
+                        self.vocabulary.inverse[i] for i in range(1, len(self.vocabulary) + 1)
                     ],
                     "word_dropout": self.word_dropout,
                 },
@@ -524,9 +481,7 @@ class WordEmbeddingsLexer(nn.Module):
             torch.save(self.state_dict(), model_path / "weights.pt")
 
     @classmethod
-    def load(
-        cls: Type[_T_WordEmbeddingsLexer], model_path: pathlib.Path
-    ) -> _T_WordEmbeddingsLexer:
+    def load(cls, model_path: pathlib.Path) -> Self:
         with open(model_path / "config.json") as in_stream:
             config = json.load(in_stream)
         res = cls(**config)
@@ -537,9 +492,7 @@ class WordEmbeddingsLexer(nn.Module):
 
     # FIXME: probably add thresholds here, at least to filter out hapax?
     @classmethod
-    def from_words(
-        cls: Type[_T_WordEmbeddingsLexer], words: Iterable[str], **kwargs
-    ) -> _T_WordEmbeddingsLexer:
+    def from_words(cls, words: Iterable[str], **kwargs) -> Self:
         vocabulary = sorted(set(words))
         return cls(vocabulary=vocabulary, **kwargs)
 
@@ -571,24 +524,16 @@ def freeze_module(module: nn.Module, freezing: bool = True):
         module.train = type(module).train  # type: ignore[assignment]
 
 
-_T_BertLexerBatch = TypeVar("_T_BertLexerBatch", bound="BertLexerBatch")
-
-
 class BertLexerBatch(NamedTuple):
     encoding: BatchEncoding
     subword_alignments: Sequence[Sequence[TokenSpan]]
 
-    def to(
-        self: _T_BertLexerBatch, device: Union[str, torch.device]
-    ) -> _T_BertLexerBatch:
+    def to(self, device: Union[str, torch.device]) -> Self:
         return type(self)(
             self.encoding.to(device=device),
             self.subword_alignments,
         )
 
-    def size(self, *args, **kwargs):
-        return self.word_indices.size(*args, **kwargs)
-
 
 class BertLexerSentence(NamedTuple):
     encoding: BatchEncoding
@@ -597,7 +542,7 @@ class BertLexerSentence(NamedTuple):
 
 def align_with_special_tokens(
     word_lengths: Sequence[int],
-    mask=Sequence[int],
+    mask: Sequence[int],
     special_tokens_code: int = 1,
     sequence_tokens_code: int = 0,
 ) -> List[TokenSpan]:
@@ -624,9 +569,6 @@ def align_with_special_tokens(
     return res
 
 
-_T_BertLexer = TypeVar("_T_BertLexer", bound="BertLexer")
-
-
 class BertLexer(nn.Module):
     """
     This Lexer performs tokenization and embedding mapping with BERT
@@ -638,10 +580,9 @@ class BertLexer(nn.Module):
         layers: Optional[Sequence[int]],
         model: transformers.PreTrainedModel,
         subwords_reduction: Literal["first", "mean"],
-        tokenizer: transformers.PreTrainedTokenizerBase,
+        tokenizer: Union[transformers.PreTrainedTokenizer, transformers.PreTrainedTokenizerFast],
         weight_layers: bool,
     ):
-
         super().__init__()
 
         self.model = model
@@ -653,12 +594,15 @@ class BertLexer(nn.Module):
             - self.tokenizer.num_special_tokens_to_add(pair=False),
         )
 
-        self.output_dim = self.model.config.hidden_size
+        self.output_dim: Final[int] = self.model.config.hidden_size
 
         # 🤗 has no unified API for the number of layers
-        num_layers = min(
-            getattr(model.config, param_name, math.inf)
-            for param_name in ("num_layers", "n_layers", "num_hidden_layers")
+        num_layers = cast(
+            int,
+            min(
+                getattr(model.config, param_name, math.inf)
+                for param_name in ("num_layers", "n_layers", "num_hidden_layers")
+            ),
         )
         if layers is None:
             layers = list(range(num_layers))
@@ -669,7 +613,7 @@ class BertLexer(nn.Module):
         self.layers = layers
         # Deactivate layerdrop if available
         if hasattr(self.model, "layerdrop"):
-            self.model.layerdrop = 0.0
+            self.model.layerdrop = 0.0  # type: ignore
         # TODO: check if the value is allowed?
         self.subwords_reduction = subwords_reduction
         self.weight_layers = weight_layers
@@ -727,16 +671,14 @@ class BertLexer(nn.Module):
                 if self.subwords_reduction == "first":
                     reduced_bert_word_embedding = this_word_subword_embeddings[0, ...]
                 elif self.subwords_reduction == "mean":
-                    reduced_bert_word_embedding = this_word_subword_embeddings.mean(
-                        dim=0
-                    )
+                    reduced_bert_word_embedding = this_word_subword_embeddings.mean(dim=0)
                 else:
                     raise ValueError(f"Unknown reduction {self.subwords_reduction}")
                 word_embeddings[sent_n, word_n, ...] = reduced_bert_word_embedding
             # Now do the root token as the average of (non-padding words) embeddings.
-            word_embeddings[sent_n, 0, ...] = word_embeddings[sent_n, ...].sum(
-                dim=0
-            ) / len(alignment)
+            word_embeddings[sent_n, 0, ...] = word_embeddings[sent_n, ...].sum(dim=0) / len(
+                alignment
+            )
 
         return word_embeddings
 
@@ -749,6 +691,9 @@ class BertLexer(nn.Module):
         for sent in batch:
             encodings_lst.append(sent.encoding)
             subwords_alignments.append(sent.subwords_alignments)
+        # TODO: figure out how to disable the warning this triggers with fast
+        # tokenizers
+        # Also why aren't we asking for tensors directly again?
         encoding = self.tokenizer.pad(encodings_lst)
         encoding.convert_to_tensors("pt")
         return BertLexerBatch(
@@ -757,7 +702,7 @@ class BertLexer(nn.Module):
         )
 
     def encode(self, tokens_sequence: Sequence[str]) -> BertLexerSentence:
-        # The root token is remved here since the BERT model has no reason to know of it
+        # The root token is removed here since the BERT model has no reason to know of it
         # FIXME: this means that this lexer is not really reusable, we should find a better way to
         # get a representations for ROOT
         unrooted_tok_sequence = tokens_sequence[1:]
@@ -766,66 +711,87 @@ class BertLexer(nn.Module):
         # awkward dance. Eventually we should be able to remove the non-fast branch here.
         if self.tokenizer.is_fast:
             bert_encoding = self.tokenizer(
-                unrooted_tok_sequence,
+                cast(PreTokenizedInput, unrooted_tok_sequence),
                 is_split_into_words=True,
+                return_length=True,
                 return_special_tokens_mask=True,
             )
-            if len(bert_encoding.data["input_ids"]) > self.max_length:
+            # Inconsistent API ugh
+            if isinstance(bert_encoding.length, list):
+                bert_encoding_length = bert_encoding.length[0]
+            else:
+                bert_encoding_length = bert_encoding.length
+            if bert_encoding_length > self.max_length:
                 raise LexingError(
-                    f"Sentence too long for this transformer model ({len(bert_encoding.data['input_ids'])} tokens > {self.max_length})",
+                    f"Sentence too long for this transformer model ({bert_encoding.length} tokens > {self.max_length})",
                     str(unrooted_tok_sequence),
                 )
             # TODO: there might be a better way to do this?
             alignments = [
-                bert_encoding.word_to_tokens(i)
-                for i in range(len(unrooted_tok_sequence))
+                bert_encoding.word_to_tokens(i) for i in range(len(unrooted_tok_sequence))
             ]
             i = next((i for i, a in enumerate(alignments) if a is None), None)
-            if i is not None:
+            if i is None:
+                return BertLexerSentence(bert_encoding, cast(List[TokenSpan], alignments))
+            logger.debug(
+                "Unencodable tokens, switching to non-fast tokenization for sentence {unrooted_tok_sequence[i]!r}."
+            )
+
+        # We end up there in two situations: when the tokenizer is not fast, or when it is fast but failed
+        # to encode all tokens and left us empty tokens, forcing us to do its job ourselves a mano
+
+        # It's annoying to have to tokenize twice but we have not better way at this point to align
+        # subtokens with the original tokens
+        bert_tokens = [self.tokenizer.tokenize(token) for token in unrooted_tok_sequence]
+        cleaned_up_unrooted_tok_sequence: Sequence[str]
+        # Maybe a list comprehension here instead to get all of them idk
+        if (i := next((i for i, s in enumerate(bert_tokens) if not s), None)) is not None:
+            if self.tokenizer.unk_token is None:
                 raise LexingError(
                     f"Unencodable token {unrooted_tok_sequence[i]!r} at {i}",
                     str(unrooted_tok_sequence),
                 )
-        else:
-            # NOTE: this might different results than tokenizing the whole sentence
-            # with some tokenizers (e.g. sentencepiece) but as far as I know, all of
-            # these have fast version, so they shouldn't land in this branch anyway.
-            bert_tokens = [
-                self.tokenizer.tokenize(token) for token in unrooted_tok_sequence
-            ]
-            i = next((i for i, s in enumerate(bert_tokens) if not s), None)
-            if i is not None:
-                if self.tokenizer.unk_token is None:
-                    raise LexingError(
-                        f"Unencodable token {unrooted_tok_sequence[i]!r} at {i}",
-                        str(unrooted_tok_sequence),
-                    )
-                else:
-                    logger.warning(
-                        f"Replacing empty words by  {self.tokenizer.unk_token} in {unrooted_tok_sequence}"
-                    )
-                    bert_tokens = [
-                        tokens if tokens else [self.tokenizer.unk_token]
-                        for tokens in bert_tokens
-                    ]
-            subtokens_sequence = [
-                subtoken for token in bert_tokens for subtoken in token
-            ]
-            if len(subtokens_sequence) > self.max_length:
-                raise LexingError(
-                    f"Sentence too long for this transformer model ({len(subtokens_sequence)} tokens > {self.max_length})",
-                    str(unrooted_tok_sequence),
+            else:
+                logger.warning(
+                    f"Replacing empty words by {self.tokenizer.unk_token!r} in {unrooted_tok_sequence}"
                 )
-            bert_encoding = self.tokenizer.encode_plus(
-                subtokens_sequence,
-                return_special_tokens_mask=True,
+                cleaned_up_unrooted_tok_sequence = [
+                    token if subtokens else self.tokenizer.unk_token
+                    for token, subtokens in zip(unrooted_tok_sequence, bert_tokens)
+                ]
+                bert_tokens = [
+                    subtokens if subtokens else [self.tokenizer.unk_token]
+                    for subtokens in bert_tokens
+                ]
+        else:
+            cleaned_up_unrooted_tok_sequence = unrooted_tok_sequence
+        bert_encoding = self.tokenizer(
+            cast(PreTokenizedInput, cleaned_up_unrooted_tok_sequence),
+            is_split_into_words=True,
+            return_length=True,
+            return_special_tokens_mask=True,
+        )
+        if isinstance(bert_encoding.length, list):
+            bert_encoding_length = bert_encoding.length[0]
+        else:
+            bert_encoding_length = bert_encoding.length
+        if bert_encoding_length > self.max_length:
+            raise LexingError(
+                f"Sentence too long for this transformer model ({bert_encoding.length} subtokens > {self.max_length})",
+                str(unrooted_tok_sequence),
             )
-            bert_word_lengths = [len(word) for word in bert_tokens]
+        bert_word_lengths = [len(word) for word in bert_tokens]
+        try:
             alignments = align_with_special_tokens(
                 bert_word_lengths,
-                bert_encoding["special_tokens_mask"],
+                bert_encoding["special_tokens_mask"],  # type: ignore
             )
-
+        except ValueError as e:
+            # Non-fast tokenizers shouldn't be prone to this
+            raise LexingError(
+                "Sentence level tokenization different from aggregated token-level tokenization.",
+                str(unrooted_tok_sequence),
+            ) from e
         return BertLexerSentence(bert_encoding, alignments)
 
     def save(self, model_path: pathlib.Path, save_weights: bool = True):
@@ -850,15 +816,13 @@ class BertLexer(nn.Module):
             torch.save(self.state_dict(), model_path / "weights.pt")
 
     @classmethod
-    def load(cls: Type[_T_BertLexer], model_path: pathlib.Path) -> _T_BertLexer:
+    def load(cls, model_path: pathlib.Path) -> Self:
         with open(model_path / "config.json") as in_stream:
             config = json.load(in_stream)
         bert_model_path = model_path / "model"
         bert_config = transformers.AutoConfig.from_pretrained(bert_model_path)
         model = transformers.AutoModel.from_config(bert_config)
-        tokenizer = transformers.AutoTokenizer.from_pretrained(
-            bert_model_path, use_fast=True
-        )
+        tokenizer = transformers.AutoTokenizer.from_pretrained(bert_model_path, use_fast=True)
         # Shim for the weird idiosyncrasies of the RoBERTa tokenizer
         if isinstance(
             tokenizer,
@@ -874,18 +838,14 @@ class BertLexer(nn.Module):
         return res
 
     @classmethod
-    def from_pretrained(
-        cls: Type[_T_BertLexer], model_name_or_path: Union[str, pathlib.Path], **kwargs
-    ) -> _T_BertLexer:
+    def from_pretrained(cls, model_name_or_path: Union[str, pathlib.Path], **kwargs) -> Self:
         try:
             model = transformers.AutoModel.from_pretrained(model_name_or_path)
         except OSError:
             config = transformers.AutoConfig.from_pretrained(model_name_or_path)
             model = transformers.AutoModel.from_config(config)
 
-        tokenizer = transformers.AutoTokenizer.from_pretrained(
-            model_name_or_path, use_fast=True
-        )
+        tokenizer = transformers.AutoTokenizer.from_pretrained(model_name_or_path, use_fast=True)
         # Shim for the weird idiosyncrasies of the RoBERTa tokenizer
         if isinstance(
             tokenizer,
